@@ -44,6 +44,10 @@ class PyflakesCommand(setuptools.Command):
         pass
 
     def run(self):
+        warnings = False
         base = self.get_finalized_command('build_py')
         for (package, module, file) in base.find_all_modules():
-            checkPath(file)
+            if checkPath(file):
+                warnings=True
+        if warnings:
+            sys.exit(1) # FAIL
